@@ -1081,12 +1081,11 @@
           suggestions = ['=', '!='];
           snippetAfter = ' ';
           if (field && field.type !== 'bool') {
-            if (field.type === 'str') {
+            if (['str', 'date', 'datetime'].indexOf(field.type) >= 0) {
               suggestions.push('~');
               suggestions.push('!~');
               snippetAfter = ' "|"';
-            } else if (field.type === 'date' || field.type === 'datetime'
-                       || field.options) {
+            } else if (field.options) {
               snippetAfter = ' "|"';
             }
             Array.prototype.push.apply(suggestions, ['>', '>=', '<', '<=']);
